@@ -1,3 +1,6 @@
+from collections import namedtuple
+
+
 class NULLMeta(type):
     def __str__(cls):
         return "<NULL>"
@@ -11,3 +14,5 @@ class NULL(metaclass=NULLMeta):
     def __new__(cls):
         return cls
 
+
+block_stack_item = namedtuple('block_stack_item', ('type', 'handler', 'level'))
